@@ -4,12 +4,6 @@
 #' tallies for the words in a vector of strings.
 #'
 #' @param x A character vector.
-#' @param as.tibble logical.  If \code{TRUE} the output class will be set to a
-#' \pkg{tibble}, otherwise a \code{\link[data.table]{data.table}}.  Default
-#' checks \code{getOption("tibble.out")} as a logical.  If this is \code{NULL}
-#' the default \code{\link[textshape]{tibble_output}} will set \code{as.tibble}
-#' to \code{TRUE} if \pkg{dplyr} is loaded.  Otherwise, the output will be a
-#' \code{\link[data.table]{data.table}}.
 #' @param \ldots ignored.
 #' @return Returns a two column \code{\link[base]{data.frame}}
 #' (\code{\link[data.table]{data.table}}) of integer tallies for the total number of
@@ -21,7 +15,7 @@
 #' sents <- c("I like excellent chicken.", "I want eggs Benedict for Festivus.")
 #' tally_both_vector(sents)
 #' tally_both_vector(presidential_debates_2012$dialogue)
-tally_both_vector <- function(x, as.tibble = tibble_output(), ...){
+tally_both_vector <- function(x, ...){
 
     count <- element_id <- NULL
 
@@ -34,5 +28,5 @@ tally_both_vector <- function(x, as.tibble = tibble_output(), ...){
     data.table::setkey(long_dat, "element_id")
     out <- long_dat[, list(short = sum(count < 3, na.rm = TRUE),
         poly = sum(count > 2, na.rm = TRUE)), by=element_id][,element_id:=NULL]
-    if_tibble(out[], as.tibble = as.tibble)
+    out[]
 }
